@@ -41,7 +41,6 @@ class EventWaiter:
       if self.done:
          return True
       if self.timeout is not None and (time.perf_counter() - self.start) > self.timeout:
-         print(util.full_exc_info())
          raise aio.TimeoutError()
       if await self.check(event):
          await self.queue.put(event)
@@ -99,10 +98,10 @@ class EventMuxer:
       # self.__lock = aio.Lock(
 
    def eventful_fut_handler(self, eventful: Eventful, fut: aio.Future):
-      if fut.result() == False:
+      if isinstance(fut.exception(), aio.exceptions.TimeoutError) or fut.result() is False:
          self.eventfuls.remove(eventful)
-      if fut.exception():
-         raise fut.exception()
+         fut.result()
+
 
    async def fire(self, ev: Event) -> None:
       # print("Firing!")
@@ -156,7 +155,6 @@ class EventRouterHost:
       await aio.gather(*[router._dispatch(event) for router_group in self.routers.values() for router in router_group])
 
 
-
 class EventRouter(util.AutoRepr):
    def __init__(self, name: str, host: EventRouterHost):
       self.name = name.lower()
@@ -206,4 +204,4 @@ class EventRouter(util.AutoRepr):
       return f"[Router: {self.name} |  <{self.muxers}>]"
 
    def __repr__(self):
-      return f"Router(name={self.name}, muxers={[m for m in self.muxers]})"
\ No newline at end of file
+      return f"Router(name={self.name}, muxers={[m for m in self.muxers]})"
